#include <iostream>
#include <QtCore>
#include <QtGui>

#include "UPlay.h"
#include "UI.h"
#include "Engine.h"

int main(int argc, char  * argv[])
{
	UPlay app(argc, argv);
	app.setApplicationName("necroplayer");

	// param	
// 	QStringList files;
// 	if (argc > 0)
// 	{
// 		int i;
// 		/*
// 		 * Add every arguments
// 		 */
// 		//QStringList files;
// 		for (i = 1; i < argc; i++)
// 		{
// 			files.append(argv[i]);
// 		}
// 		
// 		/*
// 		 * If there was a media added, play it
// 		 */
// 		if (i > 1)
// 		{
// 			app.next();
// 		}
// 	}

	// Restoring the playlist
	//app.restorePlaylist();
	
// 	app.addMedia(files);
	


	

	return app.exec();
}
